import os, glob
import NFSyndication
import subprocess
from NFSyndication import main as NFS_init
# test@
def test_conf():
    """ We use these conditions to check the statement"""
    subscriptions = [
     'http://feedpress.me/512pixels',
     'http://www.leancrew.com/all-this/feed/',
     'http://ihnatko.com/feed/',
     'http://blog.ashleynh.me/feed']
  
    with open(f'feeds.txt', 'w', encoding='utf8') as f:
     f.write(",".join(subscriptions).replace(',', '\n'))
    return NFS_init()
    
def test_entrypoint():
    """Then initialize code."""
    return NFS_init()



#!/usr/bin/python 
import sys
import colorful as cf

cfail = cf.bold_red

def init():
  try:
   from . import nfs_main, styles
  except Exception as e:
   print(cfail(f"Fatal: {e}"))
   sys.exit(1)
  
  #return os.popen(f'{dir_path}/nfs_main.py').read()
  #run = lambda filename : exec(open(filename).read(), globals())
  #return run(f'{dir_path}/main.py')
  #fload = lambda filename : exec(open(filename).read(), globals())
  #return fload(f'{dir_path}/styles.py')




# -*- coding: utf-8 -*-
import cssutils
# You can decode the cssText in ASCII using the function sheet.cssText.decode('ascii') before writing to CSS file

css = '''
       /* begin */
body {
    font: 12pt Georgia, Palatino, 'Palatino Linotype', Times, 'Times New Roman', serif;
                                        /* font: serif */
    color: #1f501f !important;           /* body-gray */
}

a {
    color: #732c7b;
}

a:hover {
    text-decoration: none;
}

a:visited {
    color: #421c52;
}

hr {
    background-color: #eee;
    height: 1px;
    border: none;
}

hr.between_posts {
    margin-top: 3em;
    margin-bottom: 3em;
}

body {
    margin: 0;
    padding: 0;
}

#header_text {
  padding: 1px 20px 0px 20px;
  color: #eeddf9;
}

#header_text a {
  color: #9aa09a !important;
  text-decoration: none;
}

img {
    margin-left:  auto;
    margin-right: auto;
    display: block;
}

code {
    margin:  2px;
    padding: 2px;
}

code, pre {
    font-family: Menlo, monospace;      /* font: mono */
    background-color: #eee;             /* light-gray */
    font-size: 0.9em;                   /* subfont-size */
}

/**
 * The overflow-x line ensures that extra text only appears within the
 * confines of the gray background, and doesn't spill out onto the page.
 * Effectively the <pre> becomes a 'window' into the code beneath.
 */
pre {
    padding: 10px;
    line-height: 1.35em;
    overflow-x: auto;
}

/*------------------------------------*
  # Footnotes
\*------------------------------------*/

/**
 * The padding-tops adds a little extra space between the bottom of an article
 * and the start of the footnote section.
 */
.footnote {
  font-size: 0.9em;                     /* subfont-size */
}

/**
 * These rules help the positioning of the footnote markers, although I'm not
 * entirely sure how they work.
 */
sup, sub {
  vertical-align: 0ex;
  position: relative;
}

sup { bottom: 1ex; }
sub { top: 0.8ex; }



/*------------------------------------*
  # Article titles
\*------------------------------------*/

.article_title a,
.permalink a,
.continue_reading {
    color: #732c7b !important;          /* primary-red */
}

.fullpost_title a {
    text-decoration: none;
    font-size: 1.5em;
    line-height: 1.5em;
}

/**
 * The article_meta class covers permalinks and posting dates
 */
.article_meta {
    font-size: 0.9em;                   /* subfont-size */
    color: #999;                        /* accent-gray */
}

.linkpost_arrow {
    color: #999;                        /* accent-gray */
}

.permalink a {
    font-size: 1.2em;
    text-decoration: none;
}

/**
 * Adjust the spacing around titles to make them look nice
 */
.linkpost_title {
    margin-bottom: -0.5em;
}

.fullpost_title {
    margin-bottom: -0.3em;
}



/*------------------------------------*
  # Blockquotes
\*------------------------------------*/

blockquote {
    border-left: 5px solid #ccc;        /* primary-red */
    margin-left:  15px;
    margin-right: 0px;
    padding: 1px 15px;
    color: #666;                        /* blockquote-gray */
    font-style: italic;
}

blockquote p {
    margin-top: 10px;
    margin-bottom: 10px;
}



/*------------------------------------*
  # Tweets
\*------------------------------------*/

/**
 * I think Dr. Drang wrote this originally?  Whatever, I have it
 * inlined so that all my CSS comes down in a single file.
 */

.bbpBox {
  width: 80%;
  background: #8ec2da;
  margin-left: auto;
  margin-right: auto;
  padding: 1em;
  margin-top: 1em;
  margin-bottom: 1.1em;
/*  margin: 1em 0em 1.1em 0em;*/
  font-family: Georgia !important;
}

.bbpBox blockquote {
  background-color: white;
  margin: 0em !important;
  padding: .75em .75em .5em .75em !important;
  -moz-border-radius: 5px;
  -webkit-border-radius: 5px;
  border-left-style: none !important;
  font-style: normal !important;
  line-height: 1.5em;
  color: #222;
}

.bbpBox blockquote a {
  color: blue;
  text-decoration: none;
}

.bbpBox blockquote a:hover {
  text-decoration: underline;
}

.bbpBox blockquote .twMeta {
  font-size: 80%;
}

.bbpBox blockquote .twContent {
  margin-bottom: 25em;
}

body {
  background-color: #140623;
  max-width: 750px;
  margin-top: 0;
  margin-left: auto;
  margin-right: auto;
  padding-top: 0;
}

h1 {
  font-size: 2.5em;
}

.rss {
  list-style-type: none;
  margin: 0;
  padding: .5em 1em 1em 1.5em;
  background-color: white;
  margin-bottom: 2em;
}

.rss li {
  margin-left: -.5em;
  line-height: 1.4;
}

.rss li pre {
  overflow: auto;
}

img, figure, iframe {
  max-width: 700px;
  height: auto !important;
}

@media screen and (max-width: 700px) {
  img, figure, iframe {
    max-width: 100% !important;
  }
}


.footnotes {
    font-size: 0.85em;
}

a code {
    text-decoration: none !important;
}

footer {
  color: #eeddf9;
  text-align: center;
  margin-bottom: 2.2em;
  font-size: 0.85em;
}

footer a {
  color: #eeddf9 !important;
} /* end */
''';

sheet = cssutils.parseString(css)

for rule in sheet:
    if rule.type == rule.STYLE_RULE:
        # find property
        for property in rule.style:
            if property.name == 'color':
                property.value = 'green'
                property.priority = 'IMPORTANT'
                break
        # or simply:
        # rule.style['margin'] = '01.0eM' # or: ('1em', 'important')  
        
        # Remind: rule.style['margin'] is not necessary.


# cssutils.ser.prefs.resolveVariables == True since 0.9.7b2
cssTextDecoded = sheet.cssText.decode('ascii')
#print(cssTextDecoded)
with open("output/style.css", 'w') as f:
    f.write(cssTextDecoded)



#!/usr/bin/python 
# -*- coding: utf-8 -*-
import os
from . import config

__version_info__ = (0,2,22)
__version__ = '.'.join(map(str,__version_info__))

__base_path__ = 'feeds.txt'

def main():
 try:
  if os.path.isfile(__base_path__) and os.access(__base_path__, os.R_OK):
    os.mkdir('output')
 except FileExistsError:
    # directory already exists
   pass
 return config.init()
 
if __name__ == '__main__':
    main()



""" Setup for NFSyndication
 See: https://packaging.python.org/guides/distributing-packages-using-setuptools/
"""

from os.path import dirname, abspath, join, exists
from setuptools import setup, find_packages
from NFSyndication import __version__

with open("README.rst", "r") as fh:
    long_description = fh.read()
 
install_reqs = [req for req in open(abspath(join(dirname(__file__), 'requirements.txt')))]

setup(
    name = "NFSyndication",
    version = __version__,
    packages=find_packages(exclude=['test', 'test.*', 'testcase.py']),
    entry_points = {
        'console_scripts': [ 
            'nfsyndication-src = NFSyndication:main',
         ]
        },
    package_data = {'NFSyndication': ['templates/*.html']},
    description= "News Feed Syndication - A package that read and fetch RSS feeds from the publications.",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    author = "Web SRC",
    author_email = "web.system.management@gmail.com",
    install_requires=install_reqs,
    license = "GNU GPL",
    keywords = "rss, news",
    project_urls={ 
        'Source': 'https://github.com/web-sys1/NFSyndication/'
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Text Processing :: Markup :: HTML'
        ]
 )
